/*
 * wmQStat - WindowMaker/AfterStep/BB/FB/Waimea dockable front-end to
 * Steve Jankowski's qstat (http://www.qstat.org/).
 *
 * Copyright (c) 2003 Alexey Dokuchaev.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: proto.h,v 1.5 2003/09/13 03:40:57 danfe Exp $
 */

#ifndef _PROTO_H_
#define _PROTO_H_

#include <stdio.h>		/* for FILE* */

#define MAX_PLAYER_NAME	32
#define MAX_SERVER_ADDR	64
#define MAX_SERVER_TYPE	3
#define MAX_MAP_NAME	16

//#define MAX_SERVER_NAME	64

#define TIME		0
#define PING		1
#define FRAGS		2

struct player
{
	char name[MAX_PLAYER_NAME + 1];
	int frags;
	int ping;
	int time;
};

struct server
{
	char type[MAX_SERVER_TYPE + 1];		/* q2s */
	char address[MAX_SERVER_ADDR + 1];	/* regency */
	//int flags;
	int npl;
	int maxpl;
	char map[MAX_MAP_NAME + 1];		/* ztn2dm3 */
	//char name[MAX_SERVER_NAME + 1];		/* Regency Meltdown */
	struct player *players;
	void (*query)(FILE *, struct player *);
};

struct slist
{
	struct server *srv;
	struct slist *next;
};

/* wmqstat.c */
void		 update_stats(void);
char		*parse_cmd_line(int, char **);
struct slist	*spawn_servers(char *);
void		 clean_up(struct slist *);
void		 draw_header(struct server *);
void		 display_stats(struct server *);
void		 wm_printf(int, int, const char *, ...);
void		 usage(void);

/* srv_proc.c */
struct server	*add_server(char *, char *);
void		 kill_server(struct server *);
int		 obtain_stats(struct server *);
void		 shut_down(struct server *, FILE *);

/* srv_query.c */
void	query_q_server(FILE *, struct player *);
void	query_qw_server(FILE *, struct player *);
void	query_q2_server(FILE *, struct player *);
void	query_hl_server(FILE *, struct player *);
void	query_trb_server(FILE *, struct player *);
void	query_trb2_server(FILE *, struct player *);
void	query_bfris_server(FILE *, struct player *);
void	query_dc3_server(FILE *, struct player *);
void	query_ghrec_server(FILE *, struct player *);

#endif /* !_PROTO_H_ */
